<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>AvancedQFile</name>
    <message>
        <location filename="../../AvancedQFile.cpp" line="26"/>
        <location filename="../../AvancedQFile.cpp" line="57"/>
        <location filename="../../AvancedQFile.cpp" line="88"/>
        <source>Not supported on this platform</source>
        <translation>Non supporté sur cette plateforme</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="40"/>
        <source>Last modified date is wrong</source>
        <translation>Date de dernière modification du fichier incorrecte</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="71"/>
        <source>Last access date is wrong</source>
        <translation>Date du dernier accès au fichier incorrecte</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="121"/>
        <source>Unknown error: %1</source>
        <translation>Erreur inconnue: %1</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="187"/>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="133"/>
        <source>Path conversion error</source>
        <translation>Erreur de conversion de chemain</translation>
    </message>
</context>
<context>
    <name>CopyEngine</name>
    <message>
        <location filename="../../CopyEngine.cpp" line="429"/>
        <location filename="../../CopyEngine.cpp" line="451"/>
        <source>The engine is forced to move, you can&apos;t copy with it</source>
        <translation>Le moteur est forcé en déplacement, vous ne pouvez pas copier avec</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="462"/>
        <location filename="../../CopyEngine.cpp" line="484"/>
        <source>The engine is forced to copy, you can&apos;t move with it</source>
        <translation>Le moteur est forcé en copie, vous ne pouvez pas déplacer avec</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="508"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="508"/>
        <source>Use the actual destination &quot;%1&quot;?</source>
        <translation>Utiliser la destination actuelle &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="732"/>
        <source>The mode has been forced previously. This is an internal error, please report it</source>
        <translation>Le mode a été forcé. C&apos;est une erreur interne, merci de la repporter</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1062"/>
        <location filename="../../CopyEngine.cpp" line="1065"/>
        <location filename="../../CopyEngine.cpp" line="1070"/>
        <location filename="../../CopyEngine.cpp" line="1074"/>
        <source>Ask</source>
        <translation>Demander</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1063"/>
        <location filename="../../CopyEngine.cpp" line="1067"/>
        <location filename="../../CopyEngine.cpp" line="1071"/>
        <location filename="../../CopyEngine.cpp" line="1075"/>
        <source>Skip</source>
        <translation>Passer</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1066"/>
        <source>Merge</source>
        <translation>Fusionner</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1068"/>
        <location filename="../../CopyEngine.cpp" line="1080"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1072"/>
        <source>Put at the end</source>
        <translation>Mettre à la fin</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1076"/>
        <source>Overwrite</source>
        <translation>Écraser</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1077"/>
        <source>Overwrite if different</source>
        <translation>Écraser si différent</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1078"/>
        <source>Overwrite if newer</source>
        <translation>Écraser si plus récent</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1079"/>
        <source>Overwrite if older</source>
        <translation>Écraser si plus vieux</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1082"/>
        <source>Automatic</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1083"/>
        <source>Sequential</source>
        <translation>Séquentiel</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1084"/>
        <source>Parallel</source>
        <translation>Parallèle</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1185"/>
        <source>Options error</source>
        <translation>Erreur d&apos;options</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1185"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>Le moteur d&apos;options n&apos;est pas chargé. Impossible d&apos;accédé aux filtres</translation>
    </message>
</context>
<context>
    <name>CopyEngineFactory</name>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="427"/>
        <location filename="../../CopyEngineFactory.cpp" line="430"/>
        <location filename="../../CopyEngineFactory.cpp" line="435"/>
        <location filename="../../CopyEngineFactory.cpp" line="439"/>
        <source>Ask</source>
        <translation>Demander</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="428"/>
        <location filename="../../CopyEngineFactory.cpp" line="432"/>
        <location filename="../../CopyEngineFactory.cpp" line="436"/>
        <location filename="../../CopyEngineFactory.cpp" line="440"/>
        <source>Skip</source>
        <translation>Passer</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="431"/>
        <source>Merge</source>
        <translation>Fusionner</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="433"/>
        <location filename="../../CopyEngineFactory.cpp" line="445"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="437"/>
        <source>Put at the end</source>
        <translation>Mettre à la fin</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="441"/>
        <source>Overwrite</source>
        <translation>Écraser</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="442"/>
        <source>Overwrite if different</source>
        <translation>Écraser si différent</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="443"/>
        <source>Overwrite if newer</source>
        <translation>Écraser si plus récent</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="444"/>
        <source>Overwrite if older</source>
        <translation>Écraser si plus vieux</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="447"/>
        <source>Automatic</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="448"/>
        <source>Sequential</source>
        <translation>Séquentiel</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="449"/>
        <source>Parallel</source>
        <translation>Parallèle</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="500"/>
        <location filename="../../CopyEngineFactory.cpp" line="539"/>
        <source>Options error</source>
        <translation>Erreur d&apos;options</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="500"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>Le moteur d&apos;options n&apos;est pas chargé. Impossible d&apos;accédé aux filtres</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="539"/>
        <source>Options engine is not loaded, can&apos;t access to the filters</source>
        <translation>Moteur d&apos;options non chargé, impossible d&apos;accéder aux filtres</translation>
    </message>
</context>
<context>
    <name>DiskSpace</name>
    <message>
        <location filename="../../DiskSpace.ui" line="14"/>
        <source>Disk space</source>
        <translation>Espace disque</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="24"/>
        <source>You need more space on this drive to finish this transfer</source>
        <translation>Vous avez besoin de plus d&apos;espace pour finir ce transfert</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="49"/>
        <source>Continue</source>
        <translation>Continuer</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="56"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.cpp" line="23"/>
        <source>Drives %1 have %2 available but need %3</source>
        <translation>Lecteur %1 as %2 disponible mais à besoin de %3</translation>
    </message>
</context>
<context>
    <name>FileErrorDialog</name>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="54"/>
        <source>Error on folder</source>
        <translation>Erreur sur un dossier</translation>
    </message>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="57"/>
        <source>Folder name</source>
        <translation>Nom de répertoire</translation>
    </message>
</context>
<context>
    <name>FileExistsDialog</name>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="137"/>
        <source>%name% - copy%suffix%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="144"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="228"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="228"/>
        <source>Try rename with using special characters</source>
        <translation>Essaie de renommage avec caratéres interdits</translation>
    </message>
</context>
<context>
    <name>FileIsSameDialog</name>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="111"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - copie</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="118"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - copie (%number%)</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="184"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="184"/>
        <source>Try rename with using special characters</source>
        <translation>Essaie de renommage avec caratéres interdits</translation>
    </message>
</context>
<context>
    <name>FilterRules</name>
    <message>
        <location filename="../../FilterRules.ui" line="33"/>
        <source>Search:</source>
        <translation>Recherche:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="43"/>
        <source>Search type:</source>
        <translation>Type de recherche:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="51"/>
        <source>Raw text</source>
        <translation>Texte brut</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="56"/>
        <source>Simplified regex</source>
        <translation>Regex simplifiée</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="61"/>
        <source>Perl&apos;s regex</source>
        <translation>Regex perl</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="69"/>
        <source>Apply on:</source>
        <translation>Appliquer sur:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="77"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="82"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="87"/>
        <source>File and folder</source>
        <translation>Fichier et dossier</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="125"/>
        <source>The test string matches with the regex</source>
        <translation>La chaine de texte corresponds avec la regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="102"/>
        <source>Checking</source>
        <translation>Vérification</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="115"/>
        <source>Test string:</source>
        <translation>Chaine de test:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="17"/>
        <source>Filters dialog</source>
        <translation>Dialogue des filtres</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="95"/>
        <source>Whole string must match</source>
        <translation>Toute la chaine doit correspondre</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="108"/>
        <source>The regex is valid</source>
        <translation>La regex est valid</translation>
    </message>
</context>
<context>
    <name>Filters</name>
    <message>
        <location filename="../../Filters.ui" line="14"/>
        <source>Filters</source>
        <translation>Filtres</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="30"/>
        <source>Exclusion filters</source>
        <translation>Filtres d&apos;exclusion</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="93"/>
        <source>Inclusion filters</source>
        <translation>Filtres d&apos;inclusion</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="105"/>
        <source>None = Include all</source>
        <translation>Aucun = tout inclure</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="93"/>
        <location filename="../../Filters.cpp" line="131"/>
        <source>Raw text</source>
        <translation>Texte brute</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="96"/>
        <location filename="../../Filters.cpp" line="134"/>
        <source>Simplified regex</source>
        <translation>Regex simplifié</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="99"/>
        <location filename="../../Filters.cpp" line="137"/>
        <source>Perl&apos;s regex</source>
        <translation>Regex perl</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="107"/>
        <location filename="../../Filters.cpp" line="145"/>
        <source>Only on file</source>
        <translation>Appliquer sur fichier</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="110"/>
        <location filename="../../Filters.cpp" line="148"/>
        <source>Only on folder</source>
        <translation>Appliquer sur dossier</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="116"/>
        <location filename="../../Filters.cpp" line="154"/>
        <location filename="../../Filters.cpp" line="216"/>
        <location filename="../../Filters.cpp" line="255"/>
        <source>Full match</source>
        <translation>Correspondance totale</translation>
    </message>
</context>
<context>
    <name>FolderExistsDialog</name>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="57"/>
        <source>Folder already exists</source>
        <translation>Dossier déjà existant</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="122"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - copie</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="131"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - copie (%number%)</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="190"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="190"/>
        <source>Try rename with using special characters</source>
        <translation>Essaie de renommage avec caratéres interdits</translation>
    </message>
</context>
<context>
    <name>ListThread</name>
    <message>
        <location filename="../../ListThread.cpp" line="1487"/>
        <location filename="../../ListThread.cpp" line="2419"/>
        <source>Unable do to move or copy item into wrong forced mode: %1</source>
        <translation>Impossible de faire un déplacement ou une copie dans le mauvais mode forcé: %1</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1494"/>
        <location filename="../../ListThread.cpp" line="2426"/>
        <source>Unable to save the transfer list: %1</source>
        <translation>Impossible de sauvegarder la liste de transfert: %1</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1510"/>
        <source>Problem reading file, or file-size is 0</source>
        <translation>Problem durant la lecture, ou taille de fichier est 0</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1517"/>
        <source>Wrong header: &quot;%1&quot;</source>
        <translation>Mauvais en-tête: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1526"/>
        <source>The transfer list is in mixed mode, but this instance is not in this mode</source>
        <translation>La liste de transfert est en mode mixte, mais l&apos;instance n&apos;est pas dans ce mode</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1535"/>
        <source>The transfer list is in copy mode, but this instance is not in this mode</source>
        <translation>La liste de transfert est en mode copie, mais l&apos;instance n&apos;est pas dans ce mode</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1541"/>
        <source>The transfer list is in move mode, but this instance is not in this mode</source>
        <translation>La liste de transfert est en mode déplacement, mais l&apos;instance n&apos;est pas dans ce mode</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1604"/>
        <source>Some errors have been found during the line parsing</source>
        <translation>Certaine erreur ont été trouvé durant l&apos;analise de la line</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1612"/>
        <source>Unable to open the transfer list: %1</source>
        <translation>Impossible d&apos;ouvrir la list de transfert: %1</translation>
    </message>
</context>
<context>
    <name>MkPath</name>
    <message>
        <location filename="../../MkPath.cpp" line="142"/>
        <source>Unable to create the folder</source>
        <translation>Impossible de créer le répertoire</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="155"/>
        <source>The source folder don&apos;t exists</source>
        <translation>Le dossier source n&apos;éxiste pas</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="183"/>
        <source>Unable to temporary rename the folder</source>
        <translation>Impossible de renommer le dossier</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="206"/>
        <source>Unable to do the final real move the folder</source>
        <translation>Impossible de faire le déplacement final du dossier</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="233"/>
        <source>Unable to move the folder</source>
        <translation>Impossible de déplacer le dossier</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="93"/>
        <location filename="../../MkPath.cpp" line="276"/>
        <source>Unable to remove</source>
        <translation>Impossible de supprimer</translation>
    </message>
</context>
<context>
    <name>ReadThread</name>
    <message>
        <location filename="../../ReadThread.cpp" line="59"/>
        <source>Internal error, please report it!</source>
        <translation>Erreur interne, merci de la reporter!</translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="188"/>
        <source>Internal error reading the source file:block size out of range</source>
        <translation>Erreur interne lisant le fichier source: taille de block hors de la plage</translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="196"/>
        <location filename="../../ReadThread.cpp" line="420"/>
        <source>Unable to read the source file: </source>
        <translation>Impossible de lire le fichier source: </translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="237"/>
        <location filename="../../ReadThread.cpp" line="468"/>
        <source>File truncated during the read, possible data change</source>
        <translatorcomment>La taille du fichier a diminué durant -&gt; changé le texte original</translatorcomment>
        <translation>Fichier a diminué durant la lecture, possible changement de données</translation>
    </message>
</context>
<context>
    <name>RenamingRules</name>
    <message>
        <location filename="../../RenamingRules.ui" line="35"/>
        <source>First renaming</source>
        <translation>Premier renommage</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="41"/>
        <source>%name% - copy%suffix%</source>
        <extracomment>%name% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="57"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; for the original file name, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; for the extra number, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; file suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="51"/>
        <source>Second renaming</source>
        <translation>Second renommage</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="39"/>
        <location filename="../../RenamingRules.cpp" line="62"/>
        <source>%1 - copy</source>
        <translation>%1 - copie</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="43"/>
        <location filename="../../RenamingRules.cpp" line="73"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - copie (%2)</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="14"/>
        <source>Renaming rules</source>
        <translation>Règles de renommage</translation>
    </message>
</context>
<context>
    <name>ScanFileOrFolder</name>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="274"/>
        <source>Blacklisted folder</source>
        <translation>Dossier banis</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="338"/>
        <source>%1 - copy</source>
        <translation>%1 - copie</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="345"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - copie (%2)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="401"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - copie</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="408"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - copie (%number%)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="444"/>
        <source>This is not a folder</source>
        <translation>N&apos;est pas un dossier</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="446"/>
        <source>The folder does exists</source>
        <translation>Le répertoire n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="448"/>
        <source>The folder is not readable</source>
        <translation>Le répertoire n&apos;est pas lisible</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="459"/>
        <source>Problem with name encoding</source>
        <translation>Problém d&apos;encodage</translation>
    </message>
</context>
<context>
    <name>TransferThread</name>
    <message>
        <location filename="../../TransferThread.cpp" line="244"/>
        <location filename="../../TransferThread.cpp" line="673"/>
        <location filename="../../TransferThread.cpp" line="745"/>
        <location filename="../../TransferThread.cpp" line="1315"/>
        <source>File not found</source>
        <translation>Fichier non trouvé</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="586"/>
        <source>Drive %1</source>
        <translation>Lecteur %1</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="588"/>
        <source>Unknown folder</source>
        <translation>Dossier inconnu</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="592"/>
        <source>root</source>
        <translation>racine</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="787"/>
        <source>The source doesn&apos;t exist</source>
        <translation>La source n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="711"/>
        <location filename="../../TransferThread.cpp" line="826"/>
        <source>The source file doesn&apos;t exist</source>
        <translation>Le fichier source n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1134"/>
        <source>The checksums do not match</source>
        <translation>Les sommes de controle ne correspondent pas</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1239"/>
        <source>Internal error: The size transfered doesn&apos;t match</source>
        <translation>Erreur interne: La taille transféré ne corresponds pas</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="751"/>
        <location filename="../../TransferThread.cpp" line="838"/>
        <source>Unable to do the folder</source>
        <translation>Impossible de créer le dossier</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="228"/>
        <source>Try rename with using special characters</source>
        <translation>Essaie de renommage avec caratéres interdits</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="346"/>
        <location filename="../../TransferThread.cpp" line="363"/>
        <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
        <translation>Mauvaise date de modification ou impossible de l&apos;avoir, vous pouvez désactiver le transfert de celui-ci</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="421"/>
        <location filename="../../TransferThread.cpp" line="444"/>
        <source>Internal error: Already opening</source>
        <translation>Erreur interne: Déjà ouvert</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="645"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - copie</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="652"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - copie (%number%)</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="832"/>
        <source>Another file exists at same place</source>
        <translation>Un autre fichier exists à la même place</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1224"/>
        <source>Internal error: The destination is not closed</source>
        <translation>Erreur interne: La destination n&apos;est pas fermé</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1250"/>
        <source>Internal error: The buffer is not empty</source>
        <translation>Erreur interne: Le buffer n&apos;est pas vide</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1315"/>
        <location filename="../../TransferThread.cpp" line="1333"/>
        <location filename="../../TransferThread.cpp" line="1348"/>
        <source>Unable to change the date</source>
        <translation>Impossible de changer la date</translation>
    </message>
</context>
<context>
    <name>WriteThread</name>
    <message>
        <location filename="../../WriteThread.cpp" line="83"/>
        <source>Path resolution error (Empty path)</source>
        <translation>Erreur de résolution de chemain (chemain vide)</translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="277"/>
        <source>Internal error, please report it!</source>
        <translation>Erreur interne, merci de la reporter!</translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="680"/>
        <source>Unable to read the source file: </source>
        <translation>Impossible de lire le fichier source: </translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="705"/>
        <source>File truncated during read, possible data change</source>
        <translation>Fichier rétréci pendant la lecture, possible changement de données</translation>
    </message>
</context>
<context>
    <name>copyEngineOptions</name>
    <message>
        <location filename="../../copyEngineOptions.ui" line="44"/>
        <source>Transfer</source>
        <translation>Transfert</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="53"/>
        <source>Move the whole folder</source>
        <translation>Déplacer le dossier complet</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="60"/>
        <source>Transfer the file rights</source>
        <translation>Transférer les droits des fichiers</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="70"/>
        <source>Keep the file date</source>
        <translation>Garder la date du fichier</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="83"/>
        <source>Autostart the transfer</source>
        <translation>Démarrer automatiquement le transfert</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="90"/>
        <location filename="../../copyEngineOptions.ui" line="110"/>
        <source>Less performance if checked</source>
        <translation>Moins de performance si coché</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="113"/>
        <source>Follow the strict order</source>
        <translation>Suivre l&apos;ordre strict</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="139"/>
        <source>Error and collision</source>
        <translation>Erreur et collision</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="145"/>
        <source>When folder error</source>
        <translation>En cas d&apos;erreur de répertoire</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="155"/>
        <source>When file error</source>
        <translation>En cas d&apos;erreur de fichier</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="181"/>
        <source>When file collision</source>
        <translation>En cas de collision de fichier</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="241"/>
        <source>When folder collision</source>
        <translation>Lors d&apos;une collision de dossier</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="272"/>
        <source>Check if destination folder exists</source>
        <translation>Vérifier si le répertoire de destination existe</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="279"/>
        <source>Renaming rules</source>
        <translation>Règles de renommage</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="299"/>
        <source>Delete partially transferred files</source>
        <translation>Supprimer les transferts partiels</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="312"/>
        <source>Rename the original destination</source>
        <translation>Renommer la destination originale</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="343"/>
        <source>Control</source>
        <translation>Controle</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="349"/>
        <source>Checksum</source>
        <translation>Somme de contrôle</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="358"/>
        <source>Only after error</source>
        <translation>Seulement après erreur</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="365"/>
        <source>Ignore if impossible</source>
        <translation>Ignorer si impossible</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="382"/>
        <source>Verify checksums</source>
        <translation>Vérifier les sommes de contrôles</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="414"/>
        <source>Performance</source>
        <translation>Performance</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="420"/>
        <source>Parallel buffer</source>
        <translation>Buffer paralléle</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="427"/>
        <location filename="../../copyEngineOptions.ui" line="440"/>
        <location filename="../../copyEngineOptions.ui" line="453"/>
        <location filename="../../copyEngineOptions.ui" line="490"/>
        <location filename="../../copyEngineOptions.ui" line="559"/>
        <source>KB</source>
        <translation>Ko</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="469"/>
        <source>Block size</source>
        <translation>Taille de bloc</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="476"/>
        <source>Sequential buffer</source>
        <translation>Buffer séquentiel</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="483"/>
        <source>Enable OS buffer</source>
        <translation>Activer le tampon de l&apos;OS</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="506"/>
        <source>OS buffer only if smaller than</source>
        <translation>Tampon de l&apos;OS seulement si plus petit que</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="513"/>
        <source>Transfer algorithm</source>
        <translation>Algorithme de transfert</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="552"/>
        <source>Parallelize if smaller than</source>
        <translation>Parallèlise si plus petit que</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="582"/>
        <source>Inode threads (unsafe &gt; 1)</source>
        <translation>Inode threads (non sécurisé&gt; 1)</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="589"/>
        <location filename="../../copyEngineOptions.ui" line="599"/>
        <source>More cpu, but better organisation on the disk</source>
        <translation>Plus de cpu mais meilleur organisation sur le disque</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="602"/>
        <source>Order the list</source>
        <translation>Ordonner la liste</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="618"/>
        <source>Misc</source>
        <translation>Divers</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="624"/>
        <source>Check the disk space</source>
        <translation>Vérifier l&apos;espace disque</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="634"/>
        <source>Use this folder when destination is not set</source>
        <translation>Utiliser ce dossier quand la destination n&apos;est pas défini</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="646"/>
        <source>Browse</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="668"/>
        <source>Filters</source>
        <translation>Filtres</translation>
    </message>
</context>
<context>
    <name>fileErrorDialog</name>
    <message>
        <location filename="../../fileErrorDialog.ui" line="14"/>
        <source>Error with file</source>
        <translation>Erreur avec un fichier</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="20"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="59"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="76"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="93"/>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="110"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="127"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="173"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Toujours faire cette action</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="193"/>
        <source>Try in with elevated privileges</source>
        <translation>Essayer avec des priviléges suppérieurs</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="200"/>
        <source>Put to bottom</source>
        <translation>Mettre à la fin</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="207"/>
        <source>Retry</source>
        <translation>Réessayer</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="214"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="221"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>fileExistsDialog</name>
    <message>
        <location filename="../../fileExistsDialog.ui" line="14"/>
        <source>The file exists</source>
        <translation>Le fichier existe</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="82"/>
        <location filename="../../fileExistsDialog.ui" line="170"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="99"/>
        <location filename="../../fileExistsDialog.ui" line="187"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="116"/>
        <location filename="../../fileExistsDialog.ui" line="204"/>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="133"/>
        <location filename="../../fileExistsDialog.ui" line="221"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="277"/>
        <source>Suggest new &amp;name</source>
        <translation>Suggérer un &amp;nouveau nom</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="288"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Toujours faire cette action</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="346"/>
        <location filename="../../fileExistsDialog.ui" line="349"/>
        <source>Overwrite if modification date differs</source>
        <translation>Écraser si les dates différes</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="308"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="315"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Écraser</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="325"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="332"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="341"/>
        <source>Overwrite if newer</source>
        <translation>Écraser si plus récent</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="354"/>
        <location filename="../../fileExistsDialog.ui" line="357"/>
        <source>Overwrite if older</source>
        <translation>Écraser si plus vieux</translation>
    </message>
</context>
<context>
    <name>fileIsSameDialog</name>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="40"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="110"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="70"/>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="14"/>
        <source>The source and destination are same</source>
        <translation>La source et la destination sont identique</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="90"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="159"/>
        <source>Suggest new &amp;name</source>
        <translation>Suggérer un &amp;nouveau nom</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="170"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Toujours faire cette action</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="190"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="197"/>
        <source>&amp;Skip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="204"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>folderExistsDialog</name>
    <message>
        <location filename="../../folderExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Source</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="14"/>
        <source>The source and destination is identical</source>
        <translation>La source et la destination sont identique</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="82"/>
        <location filename="../../folderExistsDialog.ui" line="150"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="99"/>
        <location filename="../../folderExistsDialog.ui" line="160"/>
        <source>Folder name</source>
        <translation>Nom de répertoire</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="116"/>
        <location filename="../../folderExistsDialog.ui" line="184"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="227"/>
        <source>Suggest new &amp;name</source>
        <translation>Suggérer un &amp;nouveau nom</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="238"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Toujours faire cette action</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="245"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="252"/>
        <source>Merge</source>
        <translation>Fusionner</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="259"/>
        <source>Skip</source>
        <translation>Passer</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="266"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
</TS>
